@@ -31,29 +31,33 @@ def add_github_stars(packages):
             repo = g.get_repo(github_name)
             pkg['repo_stars'] = len(list(repo.get_stargazers()))
         else:
-            print(pkg['name'], github_name)
             pkg['repo_stars'] = -1
 
 
 def add_pypi(packages):
     for pkg in packages:
-        r = urllib.request.urlopen('https://pypi.python.org/pypi/'
-                                   + pkg['pypi_name']
-                                   + '/json')
-        j = json.load(r)
-        pkg['pypi_license'] = j['info']['license']
-        pkg['pypi_version'] = j['info']['version']
+        try:
+            r = urllib.request.urlopen('https://pypi.python.org/pypi/'
+                                       + pkg['pypi_name']
+                                       + '/json')
+            j = json.load(r)
+            pkg['pypi_license'] = j['info']['license']
+            pkg['pypi_version'] = j['info']['version']
+        except urllib.error.HTTPError:
+            pkg['pypi_license'] = 'unknown'
+            pkg['pypi_version'] = 'unknown'
 
 def write_package_table(fp, packages):
     fp.write("Total {} packages, {} of them are already in Debian\n\n"
              .format(len(packages),
                      len(list(filter(lambda p: 'debian_pkg' in p, packages)))))
     for pkg in packages:
-        fp.write("{debian:1} {stars:4} {api:1} {prov:1} {name}\n".format(
+        if pkg['pypi_name'] == 'astropy':
+            continue
+        fp.write("{debian:1} {stars:4} {api:1} {name}\n".format(
             debian = '*' if 'debian_pkg' in pkg else ' ',
             stars = pkg.get('repo_stars', 0),
             api = 'S' if pkg['stable'] else 'U',
-            prov = 'P' if pkg['provisional'] else 'A',
             name = pkg['name']
         ))
 
@@ -65,40 +69,9 @@ Columns:
  - API stability
     S stable
     U unstable
- - Accepted as Astropy Affiliated package
-    A accepted
-    P provisionally accepted
  - Name
 ''')
 
-def update_control(packages):
-    from debian import deb822
-    import itertools
-    cname = 'debian/control'
-    with open(cname) as fp:
-        header, py3 = deb822.Deb822.iter_paragraphs(fp)
-    
-    py3_list = sorted(itertools.chain(*([p for p in pkg.get('debian_pkg', [])
-                                         if p.startswith("python3-")]
-                                        for pkg in packages)))
-    py3_old = sorted(p.strip() for p in py3['Recommends'].split(','))
-    py3['Recommends'] = ',\n            '.join(py3_list)
-    
-    with open(cname, 'w') as fp:
-        fp.write(('\n\n'.join('\n'.join(key + ": " + val
-                                        for key, val in par.items())
-                              for par in (header, py3))))
-        fp.write('\n')
-
-    py3_added = set(py3_list) - set(py3_old)
-    if len(py3_added):
-        print(' * Added ' + ', '.join(py3_added)
-              + ' to python3-astropy-affilliated')
-    py3_removed = set(py3_old) - set(py3_list)
-    if len(py3_removed):
-        print(' * Removed ' + ', '.join(py3_removed)
-              + ' from python3-astropy-affilliated')
-
 def write_todo(fp, packages):
     for pkg in packages:
         if 'debian_pkg' in pkg:
@@ -115,11 +88,11 @@ def write_todo(fp, packages):
 
 '''.format(**pkg))
 
-r = urllib.request.urlopen("https://www.astropy.org/affiliated/registry.json")
-registry = json.load(r)
+with urllib.request.urlopen("https://www.astropy.org/affiliated/registry.json") as r:
+    registry = json.load(r)
+
 packages = registry['packages']
 add_debian_packages(packages)
-update_control(packages)
           
 add_pypi(packages)
 add_github_stars(packages)
